@@ -30,6 +30,24 @@ var tbSyncAccountSettings = {
     viewFolderPane: null,
     updateTimer: Components.classes["@mozilla.org/timer;1"].createInstance(Components.interfaces.nsITimer),
 
+
+    stripHost: function (document, account) {
+        let host = document.getElementById('tbsync.accountsettings.pref.host').value;
+        if (host.indexOf("https://") == 0) {
+            host = host.replace("https://","");
+            document.getElementById('tbsync.accountsettings.pref.https').checked = true;
+            tbSync.db.setAccountSetting(account, "https", "1");
+        } else if (host.indexOf("http://") == 0) {
+            host = host.replace("http://","");
+            document.getElementById('tbsync.accountsettings.pref.https').checked = false;
+            tbSync.db.setAccountSetting(account, "https", "0");
+        }
+        
+        while (host.endsWith("/")) { host = host.slice(0,-1); }        
+        document.getElementById('tbsync.accountsettings.pref.host').value = host
+        tbSync.db.setAccountSetting(account, "host", host);
+    },
+
     updateFolderListObserver: {
         observe: function (aSubject, aTopic, aData) {
             //only run if is request for this account and main frame is visible
@@ -63,7 +81,10 @@ var tbSyncAccountSettings = {
                         let status = tbSync.db.getAccountSetting(account, "status");
                         switch (status) {
                             case "401":
-                                window.openDialog("chrome://tbsync/content/manager/password.xul", "passwordprompt", "centerscreen,chrome,resizable=no", tbSync.db.getAccount(account), function() {tbSync.syncAccount("sync", account);});
+                                //only popup one password prompt window
+                                if (tbSync.passWindowObj === null) {
+                                    tbSync.passWindowObj = window.openDialog("chrome://tbsync/content/manager/password.xul", "passwordprompt", "centerscreen,chrome,resizable=no", tbSync.db.getAccount(account), function() {tbSync.syncAccount("sync", account);});
+                                }
                                 break;
                         }
                     tbSyncAccountSettings.updateGui();
@@ -339,7 +360,7 @@ var tbSyncAccountSettings = {
     },
 
     unlockSettings: function () {
-        if (confirm(tbSync.getLocalizedMessage("prompt.UnlockSettings", tbSyncAccountSettings.provider))) {
+        if (confirm(tbSync.getLocalizedMessage("prompt.UnlockSettings"))) {
             tbSync.db.setAccountSetting(tbSyncAccountSettings.account, "servertype", "custom");
             tbSyncAccountSettings.loadSettings();
         }
